@@ -29,7 +29,7 @@
 #include <libdbus-monitor-session.h>
 
 #include "gpm-inhibit.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-conf.h"
 
 static void     gpm_inhibit_class_init (GpmInhibitClass *klass);
@@ -172,7 +172,7 @@ gpm_inhibit_inhibit (GpmInhibit  *inhibit,
 	if (connection == NULL ||
 	    application == NULL ||
 	    reason == NULL) {
-		gpm_warning ("Recieved Inhibit, but application "
+		egg_warning ("Recieved Inhibit, but application "
 			     "did not set the parameters correctly");
 		dbus_g_method_return (context, -1);
 		return;
@@ -187,7 +187,7 @@ gpm_inhibit_inhibit (GpmInhibit  *inhibit,
 
 	inhibit->priv->list = g_slist_append (inhibit->priv->list, (gpointer) data);
 
-	gpm_debug ("Recieved Inhibit from '%s' (%s) because '%s' saving as #%i",
+	egg_debug ("Recieved Inhibit from '%s' (%s) because '%s' saving as #%i",
 		   data->application, data->connection, data->reason, data->cookie);
 
 	/* only emit event on the first one */
@@ -231,7 +231,7 @@ gpm_inhibit_un_inhibit (GpmInhibit  *inhibit,
 				      "cannot do UnInhibit!", cookie);
 		return FALSE;
 	}
-	gpm_debug ("UnInhibit okay #%i", cookie);
+	egg_debug ("UnInhibit okay #%i", cookie);
 	gpm_inhibit_free_data_object (data);
 
 	/* remove it from the list */
@@ -255,7 +255,7 @@ gpm_inhibit_get_requests (GpmInhibit *inhibit,
 			  gchar	   ***requests,
 			  GError    **error)
 {
-	gpm_warning ("Not implimented");
+	egg_warning ("Not implimented");
 	return FALSE;
 }
 
@@ -278,7 +278,7 @@ gpm_inhibit_remove_dbus (GpmInhibit  *inhibit,
 	for (a=0; a<g_slist_length (inhibit->priv->list); a++) {
 		data = (GpmInhibitData *) g_slist_nth_data (inhibit->priv->list, a);
 		if (strcmp (data->connection, connection) == 0) {
-			gpm_debug ("Auto-revoked idle inhibit on '%s'.",
+			egg_debug ("Auto-revoked idle inhibit on '%s'.",
 				   data->application);
 			gpm_inhibit_free_data_object (data);
 			/* remove it from the list */
@@ -326,18 +326,18 @@ gpm_inhibit_has_inhibit (GpmInhibit *inhibit,
 
 	length = g_slist_length (inhibit->priv->list);
 
-	if (inhibit->priv->ignore_inhibits == TRUE) {
-		gpm_debug ("Inhibit ignored through gconf policy!");
+	if (inhibit->priv->ignore_inhibits) {
+		egg_debug ("Inhibit ignored through gconf policy!");
 		*has_inihibit = FALSE;
 	}
 
 	/* An inhibit can stop the action */
 	if (length == 0) {
-		gpm_debug ("Valid as no inhibitors");
+		egg_debug ("Valid as no inhibitors");
 		*has_inihibit = FALSE;
 	} else {
 		/* we have at least one application blocking the action */
-		gpm_debug ("We have %i valid inhibitors", length);
+		egg_debug ("We have %i valid inhibitors", length);
 		*has_inihibit = TRUE;
 	}
 
@@ -553,7 +553,7 @@ inhibit (DbusProxy       *gproxy,
 		g_error_free (error);
 		*cookie = 0;
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("Inhibit failed!");
 	}
@@ -580,7 +580,7 @@ uninhibit (DbusProxy *gproxy,
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (error) {
-		gpm_debug ("ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
 	return ret;
@@ -608,7 +608,7 @@ has_inhibit (DbusProxy *gproxy,
 		g_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("HasInhibit failed!");
 	}
@@ -625,7 +625,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	guint cookie2 = 0;
 	DbusProxy *gproxy;
 
-	if (gpm_st_start (test, "GpmInhibit", CLASS_AUTO) == FALSE) {
+	if (gpm_st_start (test, "GpmInhibit") == FALSE) {
 		return;
 	}
 
@@ -643,9 +643,9 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we are not inhibited");
 	ret = has_inhibit (gproxy, &valid);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to test validity");
-	} else if (valid == TRUE) {
+	} else if (valid) {
 		gpm_st_failed (test, "Already inhibited");
 	} else {
 		gpm_st_success (test, NULL);
@@ -654,7 +654,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "clear an invalid cookie");
 	ret = uninhibit (gproxy, 123456);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_success (test, "invalid cookie failed as expected");
 	} else {
 		gpm_st_failed (test, "should have rejected invalid cookie");
@@ -666,7 +666,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 				  "gnome-power-self-test",
 				  "test inhibit",
 				  &cookie1);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to inhibit");
 	} else if (cookie1 == 0) {
 		gpm_st_failed (test, "Cookie invalid (cookie: %u)", cookie1);
@@ -677,9 +677,9 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we are auto inhibited");
 	ret = has_inhibit (gproxy, &valid);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to test validity");
-	} else if (valid == TRUE) {
+	} else if (valid) {
 		gpm_st_success (test, "inhibited");
 	} else {
 		gpm_st_failed (test, "inhibit failed");
@@ -691,7 +691,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 				  "gnome-power-self-test",
 				  "test inhibit",
 				  &cookie2);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to inhibit");
 	} else if (cookie2 == 0) {
 		gpm_st_failed (test, "Cookie invalid (cookie: %u)", cookie2);
@@ -702,7 +702,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "clear cookie 1");
 	ret = uninhibit (gproxy, cookie1);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "cookie failed to clear");
 	} else {
 		gpm_st_success (test, NULL);
@@ -711,9 +711,9 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "make sure we are still inhibited");
 	ret = has_inhibit (gproxy, &valid);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "Unable to test validity");
-	} else if (valid == TRUE) {
+	} else if (valid) {
 		gpm_st_success (test, "inhibited");
 	} else {
 		gpm_st_failed (test, "inhibit failed");
@@ -722,7 +722,7 @@ gpm_st_inhibit (GpmSelfTest *test)
 	/************************************************************/
 	gpm_st_title (test, "clear cookie 2");
 	ret = uninhibit (gproxy, cookie2);
-	if (ret == FALSE) {
+	if (!ret) {
 		gpm_st_failed (test, "cookie failed to clear");
 	} else {
 		gpm_st_success (test, NULL);
